# `FPFS`: Fourier Power Function Shaplets (A fast, accurate shear estimator)

## Installation

```shell
git clone https://github.com/mr-superonion/FPFS.git
cd FPFS
pip install ./
```

## Demos

[demo1](https://github.com/mr-superonion/FPFS/blob/master/notebook/demos/demo1.ipynb)
simulates noisy galaxies with different SNRs and process the galaxies with FPFS
shear estimator.


## Reference
+ [version 2.0](https://ui.adsabs.harvard.edu/abs/2021arXiv211001214L/abstract)
+ [version 1.0](https://ui.adsabs.harvard.edu/abs/2018MNRAS.481.4445L/abstract)
